@@ -1,9 +1,9 @@
 /*****************************************************************************
- * RRDtool 1.3.3  Copyright by Tobi Oetiker, 1997-2008
+ * RRDtool 1.3.7  Copyright by Tobi Oetiker, 1997-2009
  *****************************************************************************
  * rrdlib.h   Public header file for librrd
  *****************************************************************************
- * $Id: rrd.h 1509 2008-09-14 20:32:10Z oetiker $
+ * $Id: rrd.h 1781 2009-04-07 07:31:53Z oetiker $
  * $Log$
  * Revision 1.9  2005/02/13 16:13:33  oetiker
  * let rrd_graph return the actual value range it picked ...
@@ -53,7 +53,15 @@ extern    "C" {
 #define _RRDLIB_H
 
 #include <sys/types.h>  /* for off_t */
+
+#ifndef WIN32
 #include <unistd.h>     /* for off_t */
+#else
+#include <string.h>
+typedef size_t ssize_t;
+typedef long off_t;
+#endif 
+
 #include <time.h>
 #include <stdio.h>      /* for FILE */
 
@@ -264,6 +272,9 @@ extern    "C" {
     rrd_context_t *rrd_get_context(
     void);
 
+#ifdef WIN32
+rrd_context_t *rrd_force_new_context(void);
+#endif
 
     int       rrd_proc_start_end(
     rrd_time_value_t *,
