@@ -1,11 +1,11 @@
 /*****************************************************************************
- * RRDtool 1.3.3  Copyright by Tobi Oetiker, 1997-2008
+ * RRDtool 1.3.7  Copyright by Tobi Oetiker, 1997-2009
  * This code is stolen from rateup (mrtg-2.x) by Dave Rand
  *****************************************************************************
  * diff calculate the difference between two very long integers available as
  *      strings
  *****************************************************************************
- * $Id: rrd_diff.c 1509 2008-09-14 20:32:10Z oetiker $
+ * $Id: rrd_diff.c 1781 2009-04-07 07:31:53Z oetiker $
  * $Log$
  * Revision 1.4  2003/03/10 00:30:34  oetiker
  * handle cases with two negative numbers
@@ -37,6 +37,10 @@
 
 #include "rrd_tool.h"
 
+#ifdef WIN32
+#include <ctype.h>
+#endif
+
 double rrd_diff(
     char *a,
     char *b)
