@@ -1,5 +1,5 @@
 /****************************************************************************
- * RRDtool 1.3.3  Copyright by Tobi Oetiker, 1997-2008
+ * RRDtool 1.3.7  Copyright by Tobi Oetiker, 1997-2009
  ****************************************************************************
  * rrd_graph_helper.c  commandline parser functions 
  *                     this code initially written by Alex van den Bogaerdt
@@ -862,6 +862,10 @@ int rrd_parse_make_vname(
         rrd_set_error("Cannot parse vname from '%s'", line);
         return 1;
     }
+    if (line[*eaten+i] == '\0') {
+        rrd_set_error("String ends after the = sign on '%s'", line);
+        return 1;
+    }
     dprintf("- found candidate '%s'\n", tmpstr);
 
     if ((gdp->vidx = find_var(im, tmpstr)) >= 0) {
