@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.3.3  Copyright by Tobi Oetiker, 1997-2008
+ * RRDtool 1.3.7  Copyright by Tobi Oetiker, 1997-2009
  * This file:     Copyright 2003 Peter Stamfest <peter@stamfest.at> 
  *                             & Tobias Oetiker
  * Distributed under the GPL
@@ -7,7 +7,7 @@
  * rrd_thread_safe.c   Contains routines used when thread safety is required
  *                     for win32
  *****************************************************************************
- * $Id: rrd_thread_safe_nt.c 1509 2008-09-14 20:32:10Z oetiker $
+ * $Id: rrd_thread_safe_nt.c 1781 2009-04-07 07:31:53Z oetiker $
  *************************************************************************** */
 
 #include <windows.h>
@@ -22,7 +22,7 @@ static CRITICAL_SECTION CriticalSection;
 
 
 /* Once-only initialisation of the key */
-static DWORD context_key_once = 0;
+static volatile LONG context_key_once = 0;
 
 
 /* Free the thread-specific rrd_context - we might actually use
@@ -51,7 +51,7 @@ rrd_context_t *rrd_get_context(
 
     context_init_context();
 
-    ctx = TlsGetValue(context_key);
+    ctx = (rrd_context_t*)(TlsGetValue(context_key));
     if (!ctx) {
         ctx = rrd_new_context();
         TlsSetValue(context_key, ctx);
@@ -59,6 +59,20 @@ rrd_context_t *rrd_get_context(
     return ctx;
 }
 
+#ifdef WIN32
+	rrd_context_t *rrd_force_new_context(void)
+	{
+		rrd_context_t *ctx;
+
+		context_init_context();
+
+		ctx = rrd_new_context();
+		TlsSetValue(context_key, ctx);
+
+		return ctx;
+	}
+#endif
+
 #undef strerror
 const char *rrd_strerror(
     int err)
